@@ -14,18 +14,18 @@ Apple::AppStoreConnect - Apple App Store Connect API client
 
 =head1 VERSION
 
-Version 0.0_1
+Version 0.1
 
 =cut
 
-our $VERSION = '0.0_1';
+our $VERSION = '0.1_1';
 
 =head1 SYNOPSIS
 
     use Apple::AppStoreConnect;
 
     my $asc = Apple::AppStoreConnect->new(
-        issuer => $API_key_issuer,  # API key issuer
+        issuer => $API_key_issuer,  # API key issuer ID
         key_id => $key_id,          # App Store Connect API key ID
         key    => $private_key      # Encrypted private key (PEM)
     );
@@ -43,7 +43,7 @@ our $VERSION = '0.0_1';
 
 Apple::AppStoreConnect provides basic access to the Apple App Store Connect API.
 
-Pease see the L<official API documentation|https://developer.apple.com/documentation/appstoreconnectapi>
+Please see the L<official API documentation|https://developer.apple.com/documentation/appstoreconnectapi>
 for usage and all possible requests.
 
 =head1 CONSTRUCTOR
@@ -76,7 +76,7 @@ On a Mac you can convert it simply:
 =item * C<key> : Instead of the C<.pem> file, you can pass its contents directly
 as a string.
 
-=item * C<key_id> : The ID of the App Store Connect ApI key created on the App Store
+=item * C<key_id> : The ID of the App Store Connect API key created on the App Store
 Connect portal  (B<Users and Access> section).
 
 =item * C<issuer> : Your API Key B<issuer ID>. Can be found at the top of the API keys
@@ -101,7 +101,7 @@ is the default method for the API requests.
 
 =item * C<expiration> : Token expiration time in seconds. Tokens are cached until
 there are less than 10 minutes left to expiration. Default: C<900> - the API will
-not accept more than 20 miuntes expiration time for most requests.
+not accept more than 20 minutes expiration time for most requests.
 
 =back
 
@@ -115,7 +115,7 @@ not accept more than 20 miuntes expiration time for most requests.
         params => \%query_params?
     );
 
-Fetchest the requested API url, by default, it will use L<JSON> to decode it
+Fetches the requested API url, by default, it will use L<JSON> to decode it
 directly to a Perl hash, unless you request C<raw> result as a string.
 
 Requires L<LWP::UserAgent>, unless the C<curl> option was set.
@@ -125,7 +125,7 @@ If the request is not successful, it will C<die> throwing the C<< HTTP::Response
 =over 4
  
 =item * C<url> : A URL to an API endpoint. Can pass the full URL, e.g. C<url =E<gt> 'https://api.appstoreconnect.apple.com/v1/apps'>,
-or you can ommit the part up to I<v1/> (i.e. C<url =E<gt> 'apps'>).
+or you can omit the part up to I<v1/> (i.e. C<url =E<gt> 'apps'>).
 
 =item * C<params> : Any other query params that you need to pass
 (see L<API documentation|https://developer.apple.com/documentation/appstoreconnectapi>).
@@ -174,7 +174,7 @@ specified in the constructor).
         params => \%query_params?
     );
 
-Without argumets it is similar to C<get(url=>"apps">, fetching the list of apps,
+Without arguments it is similar to C<get(url=E<gt>"apps">, fetching the list of apps,
 but does some extra processing to return a Perl hash with app IDs as keys and the
 app attributes as values.
 
@@ -185,7 +185,7 @@ There are optional arguments to get details of a specific app or app resource:
 =item * C<id> : The app ID. Specifying just the id will return the details for a
 single app.
 
-=item * C<path> : Requires C<id> and is equivalent to C<get(url=>"apps/$app_id/$path")>,
+=item * C<path> : Requires C<id> and is similar to C<get(url=E<gt>"apps/$app_id/$path")>,
 returning a specific resource type for an app, except it does the convenience processing
 where a hash with the ids of this resource as keys are returned and the attributes
 as values (unless the specific resource does not follow that pattern).
@@ -216,8 +216,8 @@ sub new {
         $args{key} = do { local $/; <$fh> };
     }
     $self->{key}        = \$args{key};
-    $self->{timeout}    = $args{timeout}  || 30;
-    $self->{expiration} = $args{expiration}  || 900;
+    $self->{timeout}    = $args{timeout} || 30;
+    $self->{expiration} = $args{expiration} || 900;
     $self->{ua}         = $args{ua};
     $self->{curl}       = $args{curl};
     $self->{scope}      = $args{scope};
